#ifndef HAL_SRV_H_
#define HAL_SRV_H_

/* A user who writes a server, use these callbacks to handle request commands.
 * In case of success a user return HAL_OK or a custom error message.
 */
struct hal_srv_callbacks {
	const char const *(*connect_callback)(unsigned int *inputs_sz, unsigned int *outputs_sz, int *master);
	const char const *(*read_end_callback)(void);
	const char const *(*write_end_callback)(void);
	const char const *(*read_prepare_callback)(void);
	const char const *(*write_prepare_callback)(void);
	const char const *(*write_inputs_callback)(const char inputs[HAL_IMAGE_MAX+1], unsigned int off);
	const char const *(*write_outputs_callback)(const char outputs[HAL_IMAGE_MAX+1], unsigned int off);
	const char const *(*read_inputs_callback)(char inputs[HAL_IMAGE_MAX+1], unsigned int len, unsigned int off);
	const char const *(*read_outputs_callback)(char outputs[HAL_IMAGE_MAX+1], unsigned int len, unsigned int off);
};

/* Init internals hal server structures. */
int hal_srv_init(struct io_context *io_ptr);

/* Deinit internals and free all connection resources. */
void hal_srv_deinit();

/* Add a new connection. */
void hal_srv_client_new(int wfd, int rfd);

/* Register callback handlers. */
int hal_srv_register_callbacks(struct hal_srv_callbacks *new_cb);

#endif

